==> nextcloud-jitsi-v0.16.2.tar.gz: jitsi/l10n/zh_HK.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "會議",
    "Jitsi Integration" : "Jitsi 整合",
    "Conferences" : "會議",
    "Jitsi Integration (unofficial)" : "Jitsi 整合（非官方）",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "此應用程式將 Jitsi 會議整合到 Nextcloud 中。\n\n特點：\n- 🎥 利用 Jitsi 在 Nextcloud 中輕鬆召開在線會議\n- 🔗 可共享的會議室連結\n- 🔎 在全球搜索中顯示會議室\n- ✅ 加入會議前的系統測試\n\n請閱讀[說明書] (https://github.com/nextcloud/jitsi)。",
    "Loading …" : "加載中 ...",
    "Server URL (required)" : "伺服器 URL（必填）",
    "Help link (optional)" : "幫助連結（非強制的）",
    "Display \"Join using the Jitsi app\"" : "顯示“使用 Jitsi 應用程式加入”",
    "JWT Secret (optional)" : "JWT 密碼（非強制的）",
    "JWT App ID" : "JWT App Id",
    "JWT Audience (optional)" : "JWT 觀眾（非強制的）",
    "JWT Issuer (optional)" : "JWT 發行者（非強制的）",
    "save" : "保存",
    "saved" : "已保存",
    "Saving …" : "儲存中 ...",
    "Please provide a Jitsi instance URL" : "請提供 Jitsi 實例 URL",
    "The server URL must start with https://" : "伺服器 URL 必須以 https:// 開頭",
    "It is highly recommended to set up a dedicated Jitsi instance" : "強烈建議設置專用 Jitsi 實例",
    "Please provide the App ID" : "請提供 App ID",
    "Failed to save settings" : "設定儲存失敗",
    "Failed to load settings" : "載入設定失敗",
    "Conference rooms" : "會議室",
    "Conference" : "會議",
    "Conference left" : "離開了會議",
    "Problems detected" : "檢測到問題",
    "Your browser is non-optimal:" : "您的瀏覽器不是最佳的：",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "語音和視像質量可能很差。建議使用最新的 <b>Firefox / Chrome / Chromium</b> 版本。",
    "Browser not supported" : "不支持該瀏覽器",
    "Show system check" : "顯示系統檢查",
    "Your name:" : "您的名字：",
    "Click here to join" : "點擊這裡來加入",
    "Start muted" : "開始時靜音",
    "Start with camera off" : "在開始時關閉相機",
    "Join with desktop app" : "使用桌面應用程式加入",
    "Join with mobile app" : "使用流動應用程序加入",
    "App button not working?" : "應用程式按鈕不起作用？",
    "Download the desktop app here ↗" : "在這裡下載桌上應用程式↗",
    "The mobile app is available via the app store of your choice." : "該流動應用程式可通過您選擇的應用程式商店獲得。",
    "After successful installation try the button again." : "安裝成功後再次嘗試按鈕。",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "還是不行？複製下面的連結，粘貼到 Jitsi 應用程式開始界面的輸入框裡。",
    "Link copied" : "已複製連結",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy to clipboard" : "複製到剪貼板",
    "Browser" : "瀏覽器",
    "non-optimal" : "非最優",
    "not supported" : "不支援",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "語音和視像質量可能很差。<br>建議使用最新的 <b>Firefox / Chrome / Chromium</b> 版本。",
    "Help" : "支援",
    "Camera" : "相機",
    "Name of the new room" : "新會議室名稱",
    "No conference rooms yet" : "還未有會議室",
    "Create the first room:" : "創建第一個會議室：",
    "Microphone" : "米高風",
    "Join" : "加入",
    "Delete room" : "刪除會議室",
    "Room not found" : "找不到聊天室",
    "Please check the link/URL and ask your host" : "請檢查連結/URL並詢問您的主持人",
    "Audio output" : "語音輸出",
    "Play test sound" : "播放測試聲音",
    "System check" : "系統檢查",
    "Got issues?" : "有問題?",
    "Known problems / what you can try" : "已知問題/您可以嘗試什麼",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• 接受屏幕頂部的米高風/相機存取權限",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• 通過單擊地址欄旁邊的圖標檢查米高風/相機存取權限。然後重新加載頁面。",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• 如果您有 DroidCam：連接到手機相機，然後重新加載頁面",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• 嘗試使用 Jitsi 應用程式加入（按照頁面底部的說明進行操作）",
    "No camera/microphone access" : "沒有相機/米高風存取",
    "Review your browser camera and microphone access settings" : "查看您的瀏覽器相機和米高風存取設置",
    "Click here for {browser} instructions" : "點擊此處查看 {browser} 說明",
    "Does not work?" : "不行？",
    "Click here for troubleshooting help" : "單擊此處獲取檢修幫助",
    "Conferences app not yet configured" : "會議應用程式尚未配置",
    "Please contact your administrator to set up the conferences app." : "請聯絡您的管理員以設置會議應用程式。",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "您的瀏覽器 (%1$s) 已過時，<br>不再受支持",
    "It is recommended to use the latest version of one of the following browsers:" : "建議使用以下瀏覽器之一的最新版本："
},
"nplurals=1; plural=0;");

==> nextcloud-jitsi-v0.19.0.tar.gz: jitsi/l10n/zh_HK.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "會議",
    "Jitsi Integration" : "Jitsi 整合",
    "Conferences" : "會議",
    "Jitsi Integration (unofficial)" : "Jitsi 整合（非官方）",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "此應用程式將 Jitsi 會議整合到 Nextcloud 中。\n\n特點：\n- 🎥 利用 Jitsi 在 Nextcloud 中輕鬆召開在線會議\n- 🔗 可共享的會議室連結\n- 🔎 在全球搜索中顯示會議室\n- ✅ 加入會議前的系統測試\n\n請閱讀[說明書] (https://github.com/nextcloud/jitsi)。",
    "Loading …" : "加載中 ...",
    "Server URL (required)" : "伺服器 URL（必填）",
    "Help link (optional)" : "幫助連結（非強制的）",
    "Display \"Join using the Jitsi app\"" : "顯示“使用 Jitsi 應用程式加入”",
    "JWT Secret (optional)" : "JWT 密碼（非強制的）",
    "JWT App ID" : "JWT App Id",
    "JWT Audience (optional)" : "JWT 觀眾（非強制的）",
    "JWT Issuer (optional)" : "JWT 發行者（非強制的）",
    "save" : "保存",
    "saved" : "已保存",
    "Saving …" : "儲存中 ...",
    "Please provide a Jitsi instance URL" : "請提供 Jitsi 實例 URL",
    "The server URL must start with https://" : "伺服器 URL 必須以 https:// 開頭",
    "It is highly recommended to set up a dedicated Jitsi instance" : "強烈建議設置專用 Jitsi 實例",
    "Please provide the App ID" : "請提供 App ID",
    "Failed to save settings" : "設定儲存失敗",
    "Failed to load settings" : "載入設定失敗",
    "Conference rooms" : "會議室",
    "Conference" : "會議",
    "Conference left" : "離開了會議",
    "Problems detected" : "檢測到問題",
    "Your browser is non-optimal:" : "您的瀏覽器不是最佳的：",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "音頻和視像質量可能很差。建議使用最新的 <b>Firefox / Chrome / Chromium</b> 版本。",
    "Browser not supported" : "不支持該瀏覽器",
    "Show system check" : "顯示系統檢查",
    "Your name:" : "您的名字：",
    "Click here to join" : "點擊這裡來加入",
    "Start muted" : "開始時靜音",
    "Start with camera off" : "在開始時關閉相機",
    "Join with desktop app" : "使用桌面應用程式加入",
    "Join with mobile app" : "使用流動應用程序加入",
    "App button not working?" : "應用程式按鈕不起作用？",
    "Download the desktop app here ↗" : "在這裡下載桌上應用程式↗",
    "The mobile app is available via the app store of your choice." : "該流動應用程式可通過您選擇的應用程式商店獲得。",
    "After successful installation try the button again." : "安裝成功後再次嘗試按鈕。",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "還是不行？複製下面的連結，粘貼到 Jitsi 應用程式開始界面的輸入框裡。",
    "Link copied" : "已複製連結",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy to clipboard" : "複製到剪貼板",
    "Browser" : "瀏覽器",
    "non-optimal" : "非最優",
    "not supported" : "不支援",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "音頻和視像質量可能很差。<br>建議使用最新的 <b>Firefox / Chrome / Chromium</b> 版本。",
    "Help" : "支援",
    "Camera" : "相機",
    "Name of the new room" : "新會議室名稱",
    "No conference rooms yet" : "還未有會議室",
    "Create the first room:" : "創建第一個會議室：",
    "Microphone" : "米高風",
    "Join" : "加入",
    "Delete room" : "刪除會議室",
    "Room not found" : "找不到聊天室",
    "Please check the link/URL and ask your host" : "請檢查連結/URL並詢問您的主持人",
    "Audio output" : "音頻輸出",
    "Play test sound" : "播放測試聲音",
    "System check" : "系統檢查",
    "Got issues?" : "有問題?",
    "Known problems / what you can try" : "已知問題/您可以嘗試什麼",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• 接受螢幕頂部的米高風/相機存取權限",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• 通過單擊地址欄旁邊的圖標檢查米高風/相機存取權限。然後重新加載頁面。",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• 如果您有 DroidCam：連接到手機相機，然後重新加載頁面",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• 嘗試使用 Jitsi 應用程式加入（按照頁面底部的說明進行操作）",
    "No camera/microphone access" : "沒有相機/米高風存取",
    "Review your browser camera and microphone access settings" : "查看您的瀏覽器相機和米高風存取設置",
    "Click here for {browser} instructions" : "點擊此處查看 {browser} 說明",
    "Does not work?" : "不行？",
    "Click here for troubleshooting help" : "單擊此處獲取檢修幫助",
    "Conferences app not yet configured" : "會議應用程式尚未配置",
    "Please contact your administrator to set up the conferences app." : "請聯絡您的管理員以設置會議應用程式。",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "您的瀏覽器 (%1$s) 已過時，<br>不再受支持",
    "It is recommended to use the latest version of one of the following browsers:" : "建議使用以下瀏覽器之一的最新版本："
},
"nplurals=1; plural=0;");
